import { createRouter, createWebHistory, createWebHashHistory } from 'vue-router';
import { useAuthStore } from '../store/AuthStore';
import IndexLayout from '../layouts/IndexLayout.vue'
import BlankLayout from '../layouts/BlankLayout.vue'
import LoginPage from '../pages/LoginPage.vue'
import RegisterPage from '../pages/RegisterPage.vue'
import Error404 from '../pages/errors/404.vue'

export const router = createRouter({
	history: createWebHashHistory(),
	linkActiveClass: 'active',
	routes: [
		{
			path: '/',
			component: IndexLayout,
			children: [
				{
					path: '/register',
					component: () => import('../pages/RegisterPage.vue')
				},
				{
					path: '/registererp',
					component: () => import('../pages/RegisterErpPage.vue')
				},

			]
		},
		{
			path: '/product',
			component: () => import('../layouts/ProductLayout.vue'),
			children: [
				{
					path: 'register',
					component: () => import('../pages/RegisterPage.vue')
				},
				{
					path: 'registererp',
					component: () => import('../pages/RegisterErpPage.vue')
				},
			]
		},

		{
			path: '/statistics',
			component: () => import('../layouts/ProductLayout.vue'),
			children: [
				{
					path: 'register',
					component: () => import('../pages/ProdtStat.vue')
				},
				{
					path: 'chart',
					component: () => import('../pages/StatChart.vue')
				},
			]
		},
		{
			path: '/account',
			component: BlankLayout,
			children: [
				{
					path: 'login',
					component: LoginPage
				}
			]
		},
		{
			path: '/404',
			component: Error404
		},

		{
			path: '/:pathMatch(.*)*', // '/:catchAll(.*)*', // '/:pathMatch(.*)*',
			redirect: '/404'
		}
	]
})

router.beforeEach(async (to) => {
	//	const alertStore = useAlertStore();
	//	alertStore.clear();

	// redirect to login page if not logged in and trying to access a restricted page
	const publicPages = ['/account/login'];
	const authRequired = !publicPages.includes(to.path);
	const auth = useAuthStore();

	if (authRequired && !auth.user) {
		auth.returnUrl = to.fullPath;
		return '/account/login';
	}
})