import { defineStore } from 'pinia';
import { router } from '../router/routes';
import { fetchWrapper } from '../utils/Fetch';

export const useAuthStore = defineStore('AuthStore', {
	state: () => {
		return {
			// initialize state from local storage to enable user to stay logged in
			user: JSON.parse(localStorage.getItem('user')),
			returnUrl: null,
			itemClasses: []
		};
	},
	actions: {
		formatDate(datetime) {
			return new Date(datetime.getTime() - datetime.getTimezoneOffset() * 60000).toISOString();
		},
		formatNumber(value, decimals = 2, thousandsSeparator = ',') {
			let result = ''
			try {
				result = parseFloat(value).toFixed(decimals).toString();
				if (thousandsSeparator) result = result.replace(/\B(?=(\d{3})+(?!\d))/g, thousandsSeparator)
			} catch(e) { }
			return result
		},
		async fillItemClasses() {
			if (this.itemClasses.length < 1) {
				let classes = await fetchWrapper.get('/itemclasses')
				this.itemClasses = classes?.sort((a,b)=>a.name>b.name?1:a.name<b.name?-1:0)
			}
		},
		async login(email, password) {
			let password_enc = CryptoJS.RIPEMD160(CryptoJS.enc.Utf16LE.parse(password)).toString(CryptoJS.enc.Base64);
			const user = await fetchWrapper.post('/login', { email, password: password_enc });

			// update pinia state
			this.user = user;

			// store user details and jwt in local storage to keep user logged in between page refreshes
			localStorage.setItem('user', JSON.stringify(user));
			router.push(this.returnUrl || '/');
		},
		logout() {
			this.user = null;
			localStorage.removeItem('user');
			localStorage.removeItem('menus');
			router.push('/account/login');
		}
	}
});
