import { useAuthStore } from "../store/AuthStore";
import { Loading } from "quasar";

export const fetchWrapper = {
	get: request('GET'),
	post: request('POST'),
	put: request('PUT'),
	delete: request('DELETE')
};

const baseUrl = window.config.API_URL;

function request(method) {
	return (url, body) => {
		const requestOptions = {
			method,
			headers: authHeader(baseUrl + url)
		};
		if (body) {
			requestOptions.headers['Content-Type'] = 'application/x-www-form-urlencoded';
			requestOptions.body = new URLSearchParams(body).toString();
		}
		Loading.show();
		return fetch(baseUrl + url, requestOptions).then(handleResponse).catch(e=>{
			Loading.hide();
			throw e;
		});
	}
}

// helper functions

function authHeader(url) {
	// return auth header with jwt if user is logged in and request is to the api url
	const { user } = useAuthStore();
	const isLoggedIn = !!user?.token;
	const isApiUrl = url.startsWith(config.API_URL);
	if (isLoggedIn && isApiUrl) {
		return { Authorization: `Bearer ${user.token}` };
	} else {
		return {};
	}
}

function handleResponse(response) {
	return response.text().then(text => {
		const data = text && JSON.parse(text);
		Loading.hide();
		if (!response.ok) {
			const { user, logout } = useAuthStore();
			if ([401, 403].includes(response.status) && user) {
				// auto logout if 401 Unauthorized or 403 Forbidden response returned from api
				logout();
			}

			const error = response.status + ' ' + ((data && data.message) || response.statusText);
			return Promise.reject(error);
		}

		return data;
	});
}    
